from setuptools import setup, find_packages
setup(
    name="May61bo",
    version="0.0.2",
    author="61bo",
    author_email="1926229516@qq.com",
    description="This project is only used to test whether it can be uploaded, and there is no function for the time being",

    # # 项目主页
    # url="https://github.com/sunjian-github/ezface",

    # 你要安装的包，通过 setuptools.find_packages 找到当前目录下有哪些包
    packages=find_packages()
)